#
# git clone https://git.jami.net/savoirfairelinux/jami-daemon.git
# cd jami-daemon
# DATE=$(git log -1 --format="%cd" --date=short | sed "s|-||g")
# git config tar.tar.xz.command "xz -c"
# git archive --format=tar.xz -o ../jami-daemon-${DATE}.tar.xz --prefix=jami-daemon-${DATE}/ master
#

%global gdate	20230119
%define rel	3

%define major	13
%define libname	%mklibname jami %{major}
%define devname	%mklibname jami -d

%bcond_with	system_pj

%define pjver	3b78ef1c48732d238ba284cdccb04dc6de79c54f

%bcond_with portaudio
%bcond_with dbus

Name:		jami-daemon
Version:	13.7.0
Release:	%mkrel %{?gdate:0.git%gdate.}%{rel}
Summary:	Jami is a software for secure communications with distributed architecture
Group:		System/Libraries
License:	GPLv3+
Url:		https://jami.net/
%if 0%{?gdate:1}
Source0:	jami-daemon-%{gdate}.tar.xz
%else
Source0:	https://git.jami.net/savoirfairelinux/jami-daemon/archive/%{version}/jami-daemon-%{version}.tar.gz
%endif
Source1:	https://github.com/savoirfairelinux/pjproject/archive/%{pjver}/pjproject-%{pjver}.tar.gz

Patch1:		jami-daemon-libexec.patch
Patch2:		jami-daemon-do-not-force-O3.patch

BuildRequires:	meson
BuildRequires:	asio-devel
BuildRequires:	ffmpeg-devel
BuildRequires:	gsm-devel
BuildRequires:	libnatpmp-devel
#BuildRequires:	restbed-devel
#BuildRequires:	swig
#BuildRequires:	gyp
BuildRequires:	pkgconfig(alsa)
BuildRequires:	pkgconfig(cppunit)
BuildRequires:	pkgconfig(dbus-c++-1)
BuildRequires:	pkgconfig(expat)
BuildRequires:	pkgconfig(fmt)
BuildRequires:	pkgconfig(gnutls)
BuildRequires:	pkgconfig(jack)
BuildRequires:	pkgconfig(jsoncpp)
BuildRequires:	pkgconfig(libarchive)
BuildRequires:	pkgconfig(libargon2)
BuildRequires:	pkgconfig(libgit2)
BuildRequires:	pkgconfig(libilbc)
%if %{with system_pj}
BuildRequires:	pkgconfig(libpjproject)
%endif
BuildRequires:	pkgconfig(libpulse)
BuildRequires:	pkgconfig(libsecp256k1)
BuildRequires:	pkgconfig(libudev)
BuildRequires:	pkgconfig(libupnp)
BuildRequires:	pkgconfig(libva)
BuildRequires:	pkgconfig(msgpack)
BuildRequires:	pkgconfig(nettle)
BuildRequires:	pkgconfig(opendht) >= 2.3.0
BuildRequires:	pkgconfig(opus)
%if %{with portaudio}
BuildRequires:	pkgconfig(portaudio-2.0)
%endif
BuildRequires:	pkgconfig(samplerate)
BuildRequires:	pkgconfig(sndfile)
BuildRequires:	pkgconfig(speex)
BuildRequires:	pkgconfig(speexdsp)
BuildRequires:	pkgconfig(yaml-cpp)
BuildRequires:	pkgconfig(zlib)
BuildRequires:	pkgconfig(webrtc-audio-processing)
Obsoletes:	ring-daemon < 9.6.0
Provides:	ring-daemon = %{version}-%{release}
%if ! %{with system_pj}
Provides:	bundled(pjproject) = 2.12.1
%endif

%description
Jami is a free and open source software, which allows to make encrypted audio
or video calls and to send files and messages around the world. Jami is an
official GNU package, that uses fully distributed architecture and independent
from any centralized service. Additional support for SIP communications is
provided.

#------------------------------------------------

%package -n	%{libname}
Summary:	Shared libraries for %{name}
Group:		System/Libraries
Requires:	%{name} >= %{version}-%{release}

%description -n	%{libname}
Shared libraries for %{name}.

#------------------------------------------------

%package -n	%{devname}
Summary:	Development files for %{name}
Group:		Development/Other
Requires:	%{name} = %{version}-%{release}
Requires:	%{libname} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Provides:	ring-daemon-devel = %{version}-%{release}
Obsoletes:	%{_lib}ring-devel < 9.6.0

%description -n	%{devname}
The development libraries and header files for %{name}.

#------------------------------------------------

%prep
%setup -qn jami-daemon-%{?gdate}%{?!gdate:%version}
%autopatch -p1

%if ! %{with system_pj}
# for bundled pjproject
cp -a %{SOURCE1} contrib/tarballs
mkdir -p contrib/native
%endif

%build
export CXXFLAGS="%{optflags} -std=gnu++17"
%if ! %{with system_pj}
# bundled pjproject
pushd contrib/native
  %set_build_flags
  ../bootstrap \
    --disable-downloads \
    --disable-all \
    --enable-pjproject
  %make_build \
    DISABLE_CONTRIB_CHECKSUMS=TRUE \
    PJPROJECT_VERSION=%{pjver} \
    DEPS_pjproject=
%ifnarch %{arm}
  export PKG_CONFIG_PATH=$PKG_CONFIG_PATH:./contrib/%{_host_cpu}-%{_real_vendor}-%{_host_os}/lib/pkgconfig
%else
  export PKG_CONFIG_PATH=$PKG_CONFIG_PATH:./contrib/%{_host_cpu}-%{_real_vendor}-%{_host_os}%{?_gnu}/lib/pkgconfig
%endif
popd
%endif

%meson \
	-Dportaudio=%{?with_portaudio:auto}%{!?with_portaudio:disabled} \
	-Dopensl=disabled \
	-Dinterfaces=library%{?with_dbus:,dbus}

%meson_build

%install
%meson_install

%if ! %{with system_pj}
# drop pjproject from devel reqs
sed -i -e 's/\s\+libpjproject,//g' %{buildroot}%{_libdir}/pkgconfig/jami.pc
%endif

%files
%if %{with dbus}
%{_libexecdir}/jamid
%{_mandir}/man?/jamid.?*
%{_datadir}/dbus-1/interfaces/cx.ring.Ring.*.xml
%{_datadir}/dbus-1/services/cx.ring.Ring.service
%endif
%{_datadir}/jami/
%{_metainfodir}/net.jami.daemon.metainfo.xml

%files -n %{libname}
%{_libdir}/libjami.so.%{major}{,.*}

%files -n %{devname}
%{_includedir}/jami/
%{_libdir}/libjami.so
%{_libdir}/pkgconfig/jami.pc


%changelog
* Fri Apr 28 2023 ghibo <ghibo> 13.7.0-0.git20230119.3.mga9
+ Revision: 1955270
- Do not force -O3 flags everywhere

* Sun Apr 16 2023 daviddavid <daviddavid> 13.7.0-0.git20230119.2.mga9
+ Revision: 1953316
- remove no more needed old pcre-devel build dependency

* Sat Jan 21 2023 wally <wally> 13.7.0-0.git20230119.1.mga9
+ Revision: 1934681
- update to 20230119 git snapshot
- bump bundled pjproject snapshot to fix CVE-2022-23537 and CVE-2022-23547
- disable dbus interface

* Thu Jan 19 2023 wally <wally> 13.7.0-0.git20230118.1.mga9
+ Revision: 1934395
- update to 20230118 git snapshot

* Sat Jan 14 2023 wally <wally> 13.7.0-0.git20230113.1.mga9
+ Revision: 1932845
- update to 20230113 git snapshot

* Fri Jan 06 2023 wally <wally> 13.7.0-0.git20230105.1.mga9
+ Revision: 1930720
- update to 20230105 git snapshot

* Tue Dec 27 2022 daviddavid <daviddavid> 13.4.0-0.git20220909.3.mga9
+ Revision: 1927150
- rebuild for new yaml-cpp 0.7.0

* Sun Oct 09 2022 ghibo <ghibo> 13.4.0-0.git20220909.2.mga9
+ Revision: 1895786
- Rebuilt against libfmt9

* Wed Sep 14 2022 wally <wally> 13.4.0-0.git20220909.1.mga9
+ Revision: 1888268
- new git snapshot 20220909
- bundled pjproject updated to 2.12
- rebuild for openssl 3.0.0
+ luigiwalser <luigiwalser>
- add upstream patch to fix build with ffmpeg 5.0
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild
+ mrambo3501 <mrambo3501>
- rebuild for ffmpeg 5.0
+ neoclust <neoclust>
- Rebuild against new libgit

* Sun Aug 01 2021 wally <wally> 10.1.0-0.git20210730.2.mga9
+ Revision: 1738467
- fix build on arm

* Sun Aug 01 2021 wally <wally> 10.1.0-0.git20210730.1.mga9
+ Revision: 1738460
- update bundled pjproject to 2.11.1 (mga#29317)
- update to latest git snapshot git20210730

* Sun Jan 24 2021 wally <wally> 9.6.0-0.git20210122.1.mga8
+ Revision: 1673219
- new git snapshot 20210122

* Sat Jan 09 2021 wally <wally> 9.6.0-0.git20210108.1.mga8
+ Revision: 1670012
- new git snapshot 20210108

* Tue Dec 29 2020 daviddavid <daviddavid> 9.6.0-0.git20201222.5.mga8
+ Revision: 1664700
- restbed build dependency no more needed

* Fri Dec 25 2020 wally <wally> 9.6.0-0.git20201222.4.mga8
+ Revision: 1663721
- build with natpmp

* Fri Dec 25 2020 wally <wally> 9.6.0-0.git20201222.3.mga8
+ Revision: 1663659
- obsolete old ring devel pkg

* Fri Dec 25 2020 wally <wally> 9.6.0-0.git20201222.2.mga8
+ Revision: 1663573
- provide ring-daemon-devel
- add more strict requires for devel pkg

* Thu Dec 24 2020 wally <wally> 9.6.0-0.git20201222.1.mga8
+ Revision: 1663547
- rename as jami-daemon
- new git snapshot 9.6.0-20201222
- rebuild for new libupnp 1.12.1
+ luigiwalser <luigiwalser>
- rebuild for jsoncpp
+ tv <tv>
- rebuild for new libixml
+ joequant <joequant>
- redo deps
+ daviddavid <daviddavid>
- update to latest v4.0.0 git snapshot 20200623
- rebuild for new opendht 2.1.1

* Mon Feb 17 2020 umeabot <umeabot> 4.0.0-1.git20190128.3.mga8
+ Revision: 1537510
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Fri Nov 01 2019 daviddavid <daviddavid> 4.0.0-1.git20190128.2.mga8
+ Revision: 1457243
- rebuild for new yaml-cpp 0.6.3

* Tue Jan 29 2019 daviddavid <daviddavid> 4.0.0-1.git20190128.1.mga7
+ Revision: 1361802
- update to latest v4.0.0 git snapshot 20190128

* Tue Jan 01 2019 daviddavid <daviddavid> 4.0.0-1.git20181231.1.mga7
+ Revision: 1348067
- update to latest v4.0.0 git snapshot to get libupnp 1.8 pkg to build with it
- rebuild for new libupnp 1.8.4

* Mon Nov 19 2018 akien <akien> 4.0.0-1.git20180119.4.mga7
+ Revision: 1331900
- Rebuild for yaml-cpp 0.6.2

* Thu Oct 04 2018 daviddavid <daviddavid> 4.0.0-1.git20180119.3.mga7
+ Revision: 1317738
- Mageia 7 Mass Rebuild

* Fri Apr 27 2018 daviddavid <daviddavid> 4.0.0-1.git20180119.2.mga7
+ Revision: 1222797
- rebuild for new ffmpeg 4.0

* Sun Jan 21 2018 daviddavid <daviddavid> 4.0.0-1.git20180119.1.mga7
+ Revision: 1195323
- update to latest v4.0.0 git snapshot to get libringclient pkg to build with it

* Sun Jan 07 2018 wally <wally> 4.0.0-1.git20180105.1.mga7
+ Revision: 1191358
- update to latest v4.0.0 git snapshot to get pkg to build with all new libs
- rebuild for new boost
+ daviddavid <daviddavid>
- use system libargon2
+ eatdirt <eatdirt>
- Rebuild for new jsoncpp
+ tv <tv>
- rebuild with latest boost

* Sat Jun 03 2017 akien <akien> 2.2.0-7.mga6
+ Revision: 1106077
- Rebuild for opendht 1.3.3 (fixes underlinking of msgpack)

* Tue May 02 2017 akien <akien> 2.2.0-6.mga6
+ Revision: 1098319
- Rebuild for ffmpeg 3.3

* Thu Mar 09 2017 daviddavid <daviddavid> 2.2.0-5.mga6
+ Revision: 1091142
- enable VAAPI hardware acceleration as ffmpeg 3 is now available

* Wed Mar 08 2017 akien <akien> 2.2.0-4.mga6
+ Revision: 1090255
- Rebuild for ffmpeg 3.2.4

* Tue Jan 03 2017 daviddavid <daviddavid> 2.2.0-3.mga6
+ Revision: 1079864
- rebuild against fixed restbed

* Mon Jan 02 2017 daviddavid <daviddavid> 2.2.0-2.mga6
+ Revision: 1079678
- do not build on armv5tl

* Mon Jan 02 2017 daviddavid <daviddavid> 2.2.0-1.mga6
+ Revision: 1079641
- initial package ring-daemon

